<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_our_skill extends Widget_Base {

	public function get_name() {
		return 'ova_our_skill';
	}

	public function get_title() {
		return __( 'Our Skill', 'ova-framework' );
	}

	public function get_icon() {
		return 'fa fa-circle-o-notch';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'jquery-circle-progress', OVA_PLUGIN_URI.'assets/libs/jquery_circle_progress/circle-progress.min.js', array('jquery'), false, true );
		wp_enqueue_script( 'jquery-appear', OVA_PLUGIN_URI.'assets/libs/jquery_appear/jquery.appear.js', array('jquery'), false, true );
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {


		/**********************************************
		CONTENT SECTION
		**********************************************/
		$this->start_controls_section(
			'section_heading_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
			]
		);

		$this->add_control(
			'color_value',
			[
				'label' => __( 'Color Value', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'default' => "#12a85f",
			]
		);

		$this->add_control(
			'color_empty',
			[
				'label' => __( 'Color Empty', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'default' => "#f2f2f2",
			]
		);

		$this->add_control(
			'color_number',
			[
				'label' => __( 'Color Number', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .circle strong' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'size',
			[
				'label' => __( 'Size (px)', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 150,
			]
		);

		$this->add_control(
			'thin',
			[
				'label' => __( 'Thin (px)', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 30,
			]
		);

		$this->add_control(
			'number',
			[
				'label' => __( 'Number Percent (%)', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 90,
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Analytical', 'ova-framework'),
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color Title', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .our-skill .title' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'time_duration',
			[
				'label' => __( 'Time Duration', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 1500,
			]
		);



		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();
		?>
		<div class="our-skill">
			<div data-time="<?php echo esc_attr($settings['time_duration']) ?>" data-thickness="<?php echo esc_attr($settings['thin']) ?>" class="circle" data-empty="<?php echo esc_attr($settings['color_empty']) ?>" data-color="<?php echo esc_attr($settings['color_value']) ?>" data-number="<?php echo esc_attr($settings['number']) ?>" data-size="<?php echo esc_attr($settings['size']) ?>"><strong></strong></div>
			<h3 class="title"><?php echo esc_html($settings['title']) ?></h3>
		</div>
		
		<?php

	}
// end render
}


